@@ -60,15 +60,16 @@ class CspReport(models.Model):
     """
 
     # data from CSP report
-    document_uri = models.URLField(help_text="The address of the protected resource, with any fragment component removed")
-    referrer = models.URLField(help_text="The referrer attribute of the protected resource")
-    blocked_uri = models.URLField(help_text="URI of the resource that was prevented from loading due to the policy violation, with any fragment component removed")
-    violated_directive = models.CharField(max_length=500, help_text="The policy directive that was violated")
-    original_policy = models.TextField(max_length=500, help_text="The original policy as received by the user-agent.")
+    document_uri = models.URLField(max_length=1000, help_text="The address of the protected resource, with any fragment component removed")
+    referrer = models.URLField(max_length=1000, help_text="The referrer attribute of the protected resource")
+    blocked_uri = models.URLField(max_length=1000, help_text="URI of the resource that was prevented from loading due to the policy violation, with any fragment component removed")
+    violated_directive = models.CharField(max_length=1000, help_text="The policy directive that was violated")
+    original_policy = models.TextField(null=True, max_length=1000, help_text="The original policy as received by the user-agent.")
 
     # metadata
     date_received = models.DateTimeField(auto_now_add=True, help_text="When this report was received")
     sender_ip = models.GenericIPAddressField(help_text="IP of the browser sending this report")
+    user_agent = models.CharField(max_length=1000, help_text="User-Agent of reporting browser")
 
     def __unicode__(self):
         return 'CSP Report: {0} from {1}'.format(self.blocked_uri, self.document_uri)
